# _build_config.py.in is converted into _build_config.py during the meson build process.

from __future__ import annotations


def build_config() -> dict[str, str]:
    """
    Return a dictionary containing build configuration settings.

    All dictionary keys and values are strings, for example ``False`` is
    returned as ``"False"``.

        .. versionadded:: 1.1.0
    """
    return dict(
        # Python settings
        python_version="3.12",
        python_install_dir=r"/usr/lib/python3.12/site-packages/",
        python_path=r"/scratch/2025.2_sc_70_distro_build_19MS/build/tmp/work/cortexa72-cortexa53-amd-linux/python3-contourpy/1.2.1/recipe-sysroot-native/usr/bin/nativepython3",

        # Package versions
        contourpy_version="1.2.1",
        meson_version="1.3.1",
        mesonpy_version="0.15.0",
        pybind11_version="2.13.1",

        # Misc meson settings
        meson_backend="ninja",
        build_dir=r"/scratch/2025.2_sc_70_distro_build_19MS/build/tmp/work/cortexa72-cortexa53-amd-linux/python3-contourpy/1.2.1/build/lib/contourpy/util",
        source_dir=r"/scratch/2025.2_sc_70_distro_build_19MS/build/tmp/work/cortexa72-cortexa53-amd-linux/python3-contourpy/1.2.1/contourpy-1.2.1/lib/contourpy/util",
        cross_build="True",

        # Build options
        build_options=r"-Dbuildtype=release -Db_ndebug=if-release -Db_vscrt=md -Dprefix=/usr -Dbindir=bin -Ddatadir=share -Dincludedir=include -Dinfodir=share/info -Dlibdir=lib -Dlibexecdir=libexec -Dlocalstatedir=/var -Dmandir=share/man -Dsbindir=sbin -Dsharedstatedir=/com -Dsysconfdir=/etc -Dwrap_mode=nodownload -Dvsenv=True --cross-file=/scratch/2025.2_sc_70_distro_build_19MS/build/tmp/work/cortexa72-cortexa53-amd-linux/python3-contourpy/1.2.1/meson.cross --native-file=/scratch/2025.2_sc_70_distro_build_19MS/build/tmp/work/cortexa72-cortexa53-amd-linux/python3-contourpy/1.2.1/meson.native --native-file=/scratch/2025.2_sc_70_distro_build_19MS/build/tmp/work/cortexa72-cortexa53-amd-linux/python3-contourpy/1.2.1/build/meson-python-native-file.ini",
        buildtype="release",
        cpp_std="c++17",
        debug="False",
        optimization="3",
        vsenv="True",
        b_ndebug="if-release",
        b_vscrt="from_buildtype",

        # C++ compiler
        compiler_name="gcc",
        compiler_version="13.4.0",
        linker_id="ld.bfd",
        compile_command="aarch64-amd-linux-g++ -mcpu=cortex-a72.cortex-a53+crc -mbranch-protection=standard -fstack-protector-strong -O2 -D_FORTIFY_SOURCE=2 -Wformat -Wformat-security -Werror=format-security --sysroot=/scratch/2025.2_sc_70_distro_build_19MS/build/tmp/work/cortexa72-cortexa53-amd-linux/python3-contourpy/1.2.1/recipe-sysroot",

        # Host machine
        host_cpu="aarch64",
        host_cpu_family="aarch64",
        host_cpu_endian="little",
        host_cpu_system="linux",

        # Build machine, same as host machine if not a cross_build
        build_cpu="x86_64",
        build_cpu_family="x86_64",
        build_cpu_endian="little",
        build_cpu_system="linux",
    )
